// Skeleton Dance, 2023 (first version)
// Ilê Sartuzi, programmed with Marcus Garcia


#include "Arduino.h"
#include "SoftwareSerial.h"
#include "DFRobotDFPlayerMini.h"
#include <Servo.h>

#define servosN 5    //for now xres has to have the same value as servosN!!!!!!!!
#define analogPin 0  //Pin receiving audio signal


int servoPins[]={2, 3, 4, 5, 6, 7}; // Pins used for servos <<<<<<<<<<<<<<<
             // 2=Lhand ; 3=Rhand ; 4=Lleg ; 5Rleg ; 6=head

float alphas[]={1, 1, 1, 1, 1, 1}; // alpha constant values to scale servos positions (simple multiplication), must be between 0 and 1


//Servo Objects
Servo servoObjects[6];  // create a servo object

//Relativos ao DFPlayer:
//Inicia a serial por software nos pinos 10 e 11
SoftwareSerial mySoftwareSerial(10, 11); // RX, TX

//Objeto responsável pela comunicação com o módulo MP3 (DFPlayer Mini)
DFRobotDFPlayerMini myDFPlayer;

int maxSongs = 0;


void setup() {
    
    Serial.begin(115200);
    mySoftwareSerial.begin(9600);


    //Pin do busy do dfplayer:
    pinMode(8,INPUT_PULLUP);


    for(int i=0; i<servosN; i++)    {
      servoObjects[i].attach(servoPins[i]); // attaches the servos on the pins defined on an array
      }
      

    if (!myDFPlayer.begin(mySoftwareSerial))
  {

    while (true){
      delay(0); // Code to compatible with ESP8266 watch dog.
    }
  }
 

  //Definicoes iniciais
  myDFPlayer.setTimeOut(500); //Timeout serial 500ms
  myDFPlayer.volume(30); //Volume 30
  delay(500);
  myDFPlayer.EQ(0); //Equalizacao normal

  //recupera o numero de Músicas encontradas no SD.
  maxSongs = myDFPlayer.readFileCounts(DFPLAYER_DEVICE_SD);

  //Mostra o menu de comandos
  //menu_opcoes();
  delay(100);
  myDFPlayer.play(1);
  delay(50);
   
   
}//SETUP


//LOOP
void loop() {
                        //end by (milliseconds)
  p(2400);              // 02'40
  torso(660);           // 03'06
  torso(600);           // 03'76         
  all(1440);            // 05'20
  p(1300);              // 06'50
  all(1770);            // 10'04 (divided in two)
  all(1770);            // 10'04
  p(1660);              // 11'70
  walkingalt(2710);     // 14'41
  walkingalt(845);
  walkingalt(845);      // 16'10
  p(900);               // 17'00
  walkingalt(2760);     // 19'76
  walkingalt(845);
  walkingalt(845);      // 21'46
  p(940);               // 22'40
  pulinho(1275);
  pulinho(1275);
  pulinho(1275);
  pulinho(1275);        // 27'50
  p(2900);              // 30'40
  all(1640);            // 32'04
  p(6380);              // 38'42
  torso(1380);          // 39'80
  p(200);               // ** add
  RH(500);              // 40'30
  LH(300);              // 41'00 ** (changed from 500x2 to 500 and 300 and pause)
  p(2800);              // 43'80
  torso(700);           // 44'50
  torso(640);           // 45'14
  torso(620);           // 45'76
  torso(480);           // 46'24
  p(2760);              // 49'00
  RH(680);              // 49'68
  LH(660);              // 50'34
  RL(620);              // 50'96
  LL(740);              // 51'70
  all(1720);            // 53'42
  p(980);               // 54'40
  walkingalt(2600);     // 57'00
  walkingalt(900);
  walkingalt(900);      // 58'80
  torso(1360);          // 59'76
  torsolegs(2000);      // 1'01'76
  legshands(2260);      // 1'04'02
  torso(310);           
  torso(310);           // 1'04'64
  legshands(2020);      // 1'06'66
  torso(310);           
  torso(310);           // 1'07'28
  allalt(3040);         // 1'10'32
  all(2380);            // 1'12'70 ** atraso
  legshands(1940);      // 1'14'64
  torso(340);           
  torso(340);           // 1'15'32
  legshands(1980);      // 1'17'30 
  torso(360);           
  torso(360);           // 1'18'02
  allalt(2980);         // 1'21'00
  all(2000);            // 1'23'32  
  p(320);               // **
  legshands(2800);      //         **
  legshands(2800);      // 1'29'08 **
  legshands(2000);      // 1'33'26 **
  legshands(2000);      // 1'33'26 **
  p(340);               // **
  torso(450);          
  torso(450);           // 1'34'40 ** (570 to 450)
  legsalt(2360);
  legsalt(2360);
  legsalt(2360);
  legsalt(2360);        // 1'43'84
  torso(446);
  RH(446);
  LH(446);              // 1'45'18
  torsolegs(1700);      // 1'46'98 ** (1800 to 1700)
  torso(390);
  torso(390);          // 1'47'76
  torsolegs(1440);     // 1'49'20
  torso(450);
  torso(450);          // 1'50'26 ** (530 to 450)
  torsolegs(2940);     // 1'53'20 **late (2940 to 2800)
  all(2340);           // 1'55'54
  torsolegs(1660);     // 1'57'20
  torso(450);
  torso(450);          // 1'58'28 ** (500 to 450)
  torsolegs(1680);     // 1'59'96
  torso(450);
  torso(450);          // 2'00'86
  torsolegs(2960);     // 2'03'82
  all(1640);           // 2'05'46
  torso(430);  
  torso(430);          // 2'06'32
  p(3740);             // 2'10'06
  armsaltwlegs(1780);
  armsaltwlegs(1780);  // 2'13'62 ** faster (done)
  armsaltwlegs(380);   // 2'14'00
  armsaltwlegs(1800);  
  armsaltwlegs(1800);  // 2'17'60
  armsaltwlegs(620);   // 2'18'22
  legshands(3060);     // 2'21'28
  torso(250);
  torso(250);          // 2'21'78
  LH(680);
  LH(680);             // 2'23'14
  RH(330);
  RH(330);             // 2'23'80
  LH(400);             // 2'24'20
  RH(260);
  RH(260);             // 2'24'72
  LH(480);             // 2'25'20
  RH(290);
  RH(290);             // 2'25'78
  LH(450);             // 2'26'28 ** (500 to 450)
  RH(220);
  RH(220);             // 2'26'72
  LH(580);             // 2'27'30  ** (580 to 450) back
  allalt(4350);
  allalt(4350);        // 2'36'00  ** (4350 to 4200) back
  torsolegs(1120);     // 2'37'12
  onoff(1540);         
  onoff(1540);         // 2'40'20
  torso(480);
  torso(480);          // 2'41'16
  onoff(1800);         
  onoff(1800);         // 2'45'00  ** (1920 to 1800)
  LH(1000);
  LH(1000);             
  LH(1000);            // 2'48'50   ** late (1166 to 1000)
  RH(940);
  RH(940);             // 2'49'44
  LH(900);
  LH(900);             
  LH(900);             // 2'52'30  ** (953 to 900)
  RH(400);
  RH(400);             // 2'53'30 ** (500 to 400 add pause to compensate)
  p(200);              // pause to compensate
  walkingalt(3140);    // 2'56'44
  LH(430);             
  RH(430);             // 2'57'30
  walkingalt(3100);    // 3'00'40
  LH(450);             
  RH(450);             // 3'01'30
  LH(600);             
  LH(600);             // 3'02'50
  RH(800);             // 3'03'40    ** (900 to 800)
  LH(400);             
  LH(400);             // 3'04'20
  RH(560);             // 3'04'76             
  LH(760);             // 3'05'52
  RH(280);             // 3'05'80 
  LH(720);             // 3'06'52
  RH(280);             // 3'06'80 
  LH(420);             // 3'07'22
  RH(540);             // 3'07'76 
  LH(640);             // 3'08'40
  p(600);              // 3'09'00
  armsaltwlegs(2250);  
  armsaltwlegs(2250);  
  armsaltwlegs(2250);  // 3'15'88 ** (2293 to 2250)
  p(1720);             // 3'17'60
  pulse(800);          // 3'18'40 ** good
  p(8080);             // 3'26'48
  all(1780);           // 3'28'26 ** good
  all(740);            // 3'29'00
  all(1960);           // 3'30'96
  pulse(1000);         // 3'31'96
  all(1340);           // 3'33'30
  all(1300);           // 3'34'60
  allalt(1040);        // 3'35'64
  all(1560);           // 3'37'20
  pulseinvert(1960);   // 3'39'16
  pulse(680);          // 3'39'84
  walkingalt(1280);    
  walkingalt(1280);    // 3'42'40
  p(3200);             // 3'45'80 ** (3400 TO 3200)
  pulse(600);          // 3'46'40
  p(7200);             // 3'53'60

  delay(180800);
         

    //Play novamente se terminar a faixa
      if(digitalRead(8)==1){
      delay(180800);  
      myDFPlayer.play(1);
      delay(50);
   }
}//LOOP


//LH
void LH(float tempo) {
  float dl=0;
  int nPassos = 2;//n linhas abaixo
  const unsigned int passos[][servosN] = {{180, 0, 0, 0, 0},              // Define the servo position each step
                                          {0, 0, 0, 0, 0}};
                                          
  float porcPasso[] = {50, 50};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]); //Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
      
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//LH

//RH
void RH(float tempo) {
  float dl=0;
  int nPassos = 2;//n linhas abaixo
  const unsigned int passos[][servosN] = {{0, 180, 0, 0, 0},              // Define the servo position each step
                                          {0, 0, 0, 0, 0}};
                                          
  float porcPasso[] = {50, 50}; //porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
      
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//RH

//LL
void LL(float tempo) {
  float dl=0;
  int nPassos = 2;//n linhas abaixo
  const unsigned int passos[][servosN] = {{0, 0, 180, 0, 0},              // Define the servo position each step
                                          {0, 0, 0, 0, 0}};
                                          
  float porcPasso[] = {50, 50}; //porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
      
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//LL

//RL
void RL(float tempo) {
  float dl=0;
  int nPassos = 2;//n linhas abaixo
  const unsigned int passos[][servosN] = {{0, 0, 0, 180, 0},              // Define the servo position each step
                                          {0, 0, 0, 0, 0}};
                                          
  float porcPasso[] = {50, 50};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
      
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//RL

//TORSO
void torso(float tempo) {
  float dl=0;
  int nPassos = 2;//n linhas abaixo
  const unsigned int passos[][servosN] = {{0, 0, 0, 0, 180},              // Define the servo position each step
                                          {0, 0, 0, 0, 0}};
                                          
  float porcPasso[] = {50, 50};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
      
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//TORSO


//PULINHO
void pulinho(float tempo) {
  float dl=0;
  int nPassos = 4;//n linhas abaixo
  const unsigned int passos[][servosN] = {{0, 0, 0, 0, 180},              // Define the servo position each step
                                          {0, 0, 180, 0, 0},
                                          {0, 0, 0, 180, 0},
                                          {0, 0, 0, 0, 0}};
                                          
  float porcPasso[] = {30, 30, 30, 10};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
      
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }

}//PULINHO


//ALL
void all(float tempo) {
  float dl=0;
  int nPassos = 16;//n linhas abaixo
  const unsigned int passos[][servosN] = {{0, 180, 0, 0, 0},              // Define the servo position each step
                                          {180, 50, 180, 50, 50},
                                          {0, 50, 180, 50, 180},
                                          {180, 50, 50, 50, 50},
                                          {0, 180, 180, 0, 0},
                                          {180, 0, 180, 180, 0},
                                          {0, 180, 0, 0, 180},
                                          {180, 50, 180, 50, 180},
                                          {180, 50, 50, 50, 50},
                                          {0, 180, 180, 0, 0},
                                          {180, 0, 180, 180, 0},
                                          {0, 180, 0, 0, 180},
                                          {180, 0, 180, 180, 0},
                                          {0, 180, 0, 0, 180},
                                          {180, 50, 180, 50, 180},
                                          {0, 0, 180, 0, 180}};
                                          
  float porcPasso[] = {6.25, 6.25, 6.25, 6.25, 6.25, 6.25, 6.25, 6.25, 6.25, 6.25, 6.25, 6.25, 6.25, 6.25, 6.25, 6.25};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
      
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');


   delay(t);
  }


  
}//ALL

//p
void p(int tempo) {
                                
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(0);//Write value times alpha to servo
      
    }
    
    delay(tempo);
}//p


//WALKINGALT
void walkingalt(float tempo) {
  float dl=0;
  int nPassos = 10;//n linhas abaixo
  const unsigned int passos[][servosN] = {{180, 0, 0, 180, 0},        // Define the servo position each step
                                          {0, 180, 180, 0, 0},
                                          {180, 0, 0, 180, 0},
                                          {0, 180, 180, 0, 0},
                                          {180, 0, 0, 180, 0}, 
                                          {0, 180, 180, 0, 0},
                                          {180, 0, 0, 180, 0},
                                          {0, 180, 180, 0, 0},
                                          {180, 0, 0, 180, 0},
                                          {0, 180, 180, 0, 0}};
                                          
  float porcPasso[] = {10, 10, 10, 10, 10, 10, 10, 10, 10, 10};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//WALKINGALT


//TORSOLEGS
void torsolegs(float tempo) {
  float dl=0;
  int nPassos = 12;//n linhas abaixo
  const unsigned int passos[][servosN] = {{0, 0, 180, 180, 180},        // Define the servo position each step
                                          {0, 0, 0, 0, 0},
                                          {0, 0, 180, 180, 180},
                                          {0, 0, 0, 0, 0},
                                          {0, 0, 180, 180, 180}, 
                                          {0, 0, 0, 0, 0},
                                          {0, 0, 180, 180, 180},
                                          {0, 0, 0, 0, 0},
                                          {0, 0, 180, 180, 180},
                                          {0, 0, 0, 0, 0},
                                          {0, 0, 180, 180, 180},
                                          {0, 0, 0, 0, 0}};
                                          
  float porcPasso[] = {8.3, 8.3, 8.3, 8.3, 8.3, 8.3, 8.3, 8.3, 8.3, 8.3, 8.3, 8.3};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//TORSOLEGS

//LEGSHANDS
void legshands(float tempo) {
  float dl=0;
  int nPassos = 6;//n linhas abaixo
  const unsigned int passos[][servosN] = {{180, 0, 180, 0, 0},        // Define the servo position each step
                                          {0, 180, 0, 180, 0},
                                          {180, 0, 180, 0, 0},
                                          {0, 180, 0, 180, 0},
                                          {180, 0, 180, 0, 0},
                                          {0, 180, 0, 180, 0}};
                                      
                                          
  float porcPasso[] = {16.6, 16.6, 16.6, 16.6, 16.6, 16.6};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//LEGSHANDS

//ALLALT
void allalt(float tempo) {
  float dl=0;
  int nPassos = 8;//n linhas abaixo
  const unsigned int passos[][servosN] = {{0, 180, 0, 180, 180},              // Define the servo position each step
                                          {180, 0, 180, 0, 0},
                                          {0, 180, 0, 180, 180},
                                          {180, 0, 180, 0, 0},
                                          {0, 180, 0, 180, 180},
                                          {180, 0, 180, 0, 0},
                                          {0, 180, 0, 180, 180},
                                          {180, 0, 180, 0, 0}};
                                          
  float porcPasso[] = {12.5, 12.5, 12.5, 12.5, 12.5, 12.5, 12.5, 12.5};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
      
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');


   delay(t);
  }
  
}//ALLALT


//LEGSALT
void legsalt(float tempo) {
  float dl=0;
  int nPassos = 6;//n linhas abaixo
  const unsigned int passos[][servosN] = {{0, 0, 180, 0, 0},        // Define the servo position each step
                                          {0, 0, 0, 180, 0},
                                          {0, 0, 180, 0, 0},
                                          {0, 0, 0, 180, 0},
                                          {0, 0, 180, 0, 0},
                                          {0, 0, 0, 180, 0}};
                                      
                                          
  float porcPasso[] = {16.6, 16.6, 16.6, 16.6, 16.6, 16.6};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//LEGSALT

//ARMSALTWLEGS
void armsaltwlegs(float tempo) {
  float dl=0;
  int nPassos = 8;//n linhas abaixo
  const unsigned int passos[][servosN] = {{180, 0, 180, 0, 0},        // Define the servo position each step
                                          {0, 180, 180, 0, 0},
                                          {180, 0, 0, 180, 0},
                                          {0, 180, 0, 180, 0},
                                          {180, 0, 180, 0, 0},
                                          {0, 180, 180, 0, 0},
                                          {180, 0, 0, 180, 0},
                                          {0, 180, 0, 180, 0}};
                                      
                                          
  float porcPasso[] = {12.5, 12.5, 12.5, 12.5, 12.5, 12.5, 12.5, 12.5};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//ARMSALTWLEGS


//ONOFF
void onoff(float tempo) {
  float dl=0;
  int nPassos = 8;//n linhas abaixo
  const unsigned int passos[][servosN] = {{180, 180, 180, 180, 180},        // Define the servo position each step
                                          {0, 0, 0, 0, 0},
                                          {180, 180, 180, 180, 180},
                                          {0, 0, 0, 0, 0},
                                          {180, 180, 180, 180, 180},
                                          {0, 0, 0, 0, 0},
                                          {180, 180, 180, 180, 180},
                                          {0, 0, 0, 0, 0}};
                                      
                                          
  float porcPasso[] = {12.5, 12.5, 12.5, 12.5, 12.5, 12.5, 12.5, 12.5};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//ONOFF

//PULSE
void pulse(float tempo) {
  float dl=0;
  int nPassos = 2;//n linhas abaixo
  const unsigned int passos[][servosN] = {{180, 180, 180, 180, 180},        // Define the servo position each step
                                          {0, 0, 0, 0, 0}};
                                      
                                          
  float porcPasso[] = {20, 80};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//PULSE


//PULSEINVERT
void pulseinvert(float tempo) {
  float dl=0;
  int nPassos = 2;//n linhas abaixo
  const unsigned int passos[][servosN] = {{180, 180, 180, 180, 180},        // Define the servo position each step
                                          {0, 0, 0, 0, 0}};
                                      
                                          
  float porcPasso[] = {80, 20};//porcentagem de tempo em cada etapa, teoricamente deve somar 100
  
  for(int i = 0; i < nPassos; i++){
    for(int j = 0; j < servosN; j++){
      
      servoObjects[j].write(passos[i][j]);//Write value times alpha to servo
      //Serial.print(passos[i][j]);
      //Serial.print(' ');
     
    }
    dl = tempo*porcPasso[i];
    dl = dl/100;
    int t=dl;

    //Serial.println(' ');

   delay(t);
  }
  
}//PULSEINVERT
